@@ -6,7 +6,7 @@ def parameter_path(name: str, key: str = None) -> str:
 
 def task_output_path(node_id: str, name: str, key: str = None) -> str:
     if key:
-        return f"{{{{tasks.{node_id}.outputs.parameters.{name}.{key}}}}}"
+        return f"{{{{= jsonpath(tasks['{node_id}'].outputs.parameters['{name}'], '$.{key}') }}}}"
     return f"{{{{tasks.{node_id}.outputs.parameters.{name}}}}}"
 
 
